==> openshift-model-config-6.2.0-sources.jar: io/fabric8/openshift/api/model/config/v1/IdentityProviderFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface IdentityProviderFluent<A extends IdentityProviderFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildBasicAuth instead.
   * @return The buildable object.
   */
  @Deprecated
  public BasicAuthIdentityProvider getBasicAuth();
  public BasicAuthIdentityProvider buildBasicAuth();
  public A withBasicAuth(BasicAuthIdentityProvider basicAuth);
  public Boolean hasBasicAuth();
  public IdentityProviderFluent.BasicAuthNested<A> withNewBasicAuth();
  public IdentityProviderFluent.BasicAuthNested<A> withNewBasicAuthLike(BasicAuthIdentityProvider item);
  public IdentityProviderFluent.BasicAuthNested<A> editBasicAuth();
  public IdentityProviderFluent.BasicAuthNested<A> editOrNewBasicAuth();
  public IdentityProviderFluent.BasicAuthNested<A> editOrNewBasicAuthLike(BasicAuthIdentityProvider item);
  
  /**
   * This method has been deprecated, please use method buildGithub instead.
   * @return The buildable object.
   */
  @Deprecated
  public GitHubIdentityProvider getGithub();
  public GitHubIdentityProvider buildGithub();
  public A withGithub(GitHubIdentityProvider github);
  public Boolean hasGithub();
  public IdentityProviderFluent.GithubNested<A> withNewGithub();
  public IdentityProviderFluent.GithubNested<A> withNewGithubLike(GitHubIdentityProvider item);
  public IdentityProviderFluent.GithubNested<A> editGithub();
  public IdentityProviderFluent.GithubNested<A> editOrNewGithub();
  public IdentityProviderFluent.GithubNested<A> editOrNewGithubLike(GitHubIdentityProvider item);
  
  /**
   * This method has been deprecated, please use method buildGitlab instead.
   * @return The buildable object.
   */
  @Deprecated
  public GitLabIdentityProvider getGitlab();
  public GitLabIdentityProvider buildGitlab();
  public A withGitlab(GitLabIdentityProvider gitlab);
  public Boolean hasGitlab();
  public IdentityProviderFluent.GitlabNested<A> withNewGitlab();
  public IdentityProviderFluent.GitlabNested<A> withNewGitlabLike(GitLabIdentityProvider item);
  public IdentityProviderFluent.GitlabNested<A> editGitlab();
  public IdentityProviderFluent.GitlabNested<A> editOrNewGitlab();
  public IdentityProviderFluent.GitlabNested<A> editOrNewGitlabLike(GitLabIdentityProvider item);
  
  /**
   * This method has been deprecated, please use method buildGoogle instead.
   * @return The buildable object.
   */
  @Deprecated
  public GoogleIdentityProvider getGoogle();
  public GoogleIdentityProvider buildGoogle();
  public A withGoogle(GoogleIdentityProvider google);
  public Boolean hasGoogle();
  public IdentityProviderFluent.GoogleNested<A> withNewGoogle();
  public IdentityProviderFluent.GoogleNested<A> withNewGoogleLike(GoogleIdentityProvider item);
  public IdentityProviderFluent.GoogleNested<A> editGoogle();
  public IdentityProviderFluent.GoogleNested<A> editOrNewGoogle();
  public IdentityProviderFluent.GoogleNested<A> editOrNewGoogleLike(GoogleIdentityProvider item);
  
  /**
   * This method has been deprecated, please use method buildHtpasswd instead.
   * @return The buildable object.
   */
  @Deprecated
  public HTPasswdIdentityProvider getHtpasswd();
  public HTPasswdIdentityProvider buildHtpasswd();
  public A withHtpasswd(HTPasswdIdentityProvider htpasswd);
  public Boolean hasHtpasswd();
  public IdentityProviderFluent.HtpasswdNested<A> withNewHtpasswd();
  public IdentityProviderFluent.HtpasswdNested<A> withNewHtpasswdLike(HTPasswdIdentityProvider item);
  public IdentityProviderFluent.HtpasswdNested<A> editHtpasswd();
  public IdentityProviderFluent.HtpasswdNested<A> editOrNewHtpasswd();
  public IdentityProviderFluent.HtpasswdNested<A> editOrNewHtpasswdLike(HTPasswdIdentityProvider item);
  
  /**
   * This method has been deprecated, please use method buildKeystone instead.
   * @return The buildable object.
   */
  @Deprecated
  public KeystoneIdentityProvider getKeystone();
  public KeystoneIdentityProvider buildKeystone();
  public A withKeystone(KeystoneIdentityProvider keystone);
  public Boolean hasKeystone();
  public IdentityProviderFluent.KeystoneNested<A> withNewKeystone();
  public IdentityProviderFluent.KeystoneNested<A> withNewKeystoneLike(KeystoneIdentityProvider item);
  public IdentityProviderFluent.KeystoneNested<A> editKeystone();
  public IdentityProviderFluent.KeystoneNested<A> editOrNewKeystone();
  public IdentityProviderFluent.KeystoneNested<A> editOrNewKeystoneLike(KeystoneIdentityProvider item);
  
  /**
   * This method has been deprecated, please use method buildLdap instead.
   * @return The buildable object.
   */
  @Deprecated
  public LDAPIdentityProvider getLdap();
  public LDAPIdentityProvider buildLdap();
  public A withLdap(LDAPIdentityProvider ldap);
  public Boolean hasLdap();
  public IdentityProviderFluent.LdapNested<A> withNewLdap();
  public IdentityProviderFluent.LdapNested<A> withNewLdapLike(LDAPIdentityProvider item);
  public IdentityProviderFluent.LdapNested<A> editLdap();
  public IdentityProviderFluent.LdapNested<A> editOrNewLdap();
  public IdentityProviderFluent.LdapNested<A> editOrNewLdapLike(LDAPIdentityProvider item);
  public String getMappingMethod();
  public A withMappingMethod(String mappingMethod);
  public Boolean hasMappingMethod();
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  
  /**
   * This method has been deprecated, please use method buildOpenID instead.
   * @return The buildable object.
   */
  @Deprecated
  public OpenIDIdentityProvider getOpenID();
  public OpenIDIdentityProvider buildOpenID();
  public A withOpenID(OpenIDIdentityProvider openID);
  public Boolean hasOpenID();
  public IdentityProviderFluent.OpenIDNested<A> withNewOpenID();
  public IdentityProviderFluent.OpenIDNested<A> withNewOpenIDLike(OpenIDIdentityProvider item);
  public IdentityProviderFluent.OpenIDNested<A> editOpenID();
  public IdentityProviderFluent.OpenIDNested<A> editOrNewOpenID();
  public IdentityProviderFluent.OpenIDNested<A> editOrNewOpenIDLike(OpenIDIdentityProvider item);
  
  /**
   * This method has been deprecated, please use method buildRequestHeader instead.
   * @return The buildable object.
   */
  @Deprecated
  public RequestHeaderIdentityProvider getRequestHeader();
  public RequestHeaderIdentityProvider buildRequestHeader();
  public A withRequestHeader(RequestHeaderIdentityProvider requestHeader);
  public Boolean hasRequestHeader();
  public IdentityProviderFluent.RequestHeaderNested<A> withNewRequestHeader();
  public IdentityProviderFluent.RequestHeaderNested<A> withNewRequestHeaderLike(RequestHeaderIdentityProvider item);
  public IdentityProviderFluent.RequestHeaderNested<A> editRequestHeader();
  public IdentityProviderFluent.RequestHeaderNested<A> editOrNewRequestHeader();
  public IdentityProviderFluent.RequestHeaderNested<A> editOrNewRequestHeaderLike(RequestHeaderIdentityProvider item);
  public String getType();
  public A withType(String type);
  public Boolean hasType();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface BasicAuthNested<N> extends Nested<N>,BasicAuthIdentityProviderFluent<IdentityProviderFluent.BasicAuthNested<N>>{
    public N and();
    public N endBasicAuth();
    
  }
  public interface GithubNested<N> extends Nested<N>,GitHubIdentityProviderFluent<IdentityProviderFluent.GithubNested<N>>{
    public N and();
    public N endGithub();
    
  }
  public interface GitlabNested<N> extends Nested<N>,GitLabIdentityProviderFluent<IdentityProviderFluent.GitlabNested<N>>{
    public N and();
    public N endGitlab();
    
  }
  public interface GoogleNested<N> extends Nested<N>,GoogleIdentityProviderFluent<IdentityProviderFluent.GoogleNested<N>>{
    public N and();
    public N endGoogle();
    
  }
  public interface HtpasswdNested<N> extends Nested<N>,HTPasswdIdentityProviderFluent<IdentityProviderFluent.HtpasswdNested<N>>{
    public N and();
    public N endHtpasswd();
    
  }
  public interface KeystoneNested<N> extends Nested<N>,KeystoneIdentityProviderFluent<IdentityProviderFluent.KeystoneNested<N>>{
    public N and();
    public N endKeystone();
    
  }
  public interface LdapNested<N> extends Nested<N>,LDAPIdentityProviderFluent<IdentityProviderFluent.LdapNested<N>>{
    public N and();
    public N endLdap();
    
  }
  public interface OpenIDNested<N> extends Nested<N>,OpenIDIdentityProviderFluent<IdentityProviderFluent.OpenIDNested<N>>{
    public N and();
    public N endOpenID();
    
  }
  public interface RequestHeaderNested<N> extends Nested<N>,RequestHeaderIdentityProviderFluent<IdentityProviderFluent.RequestHeaderNested<N>>{
    public N and();
    public N endRequestHeader();
    
  }
  
}

==> openshift-model-config-6.7.2-sources.jar: io/fabric8/openshift/api/model/config/v1/IdentityProviderFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface IdentityProviderFluent<A extends IdentityProviderFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildBasicAuth instead.
   * @return The buildable object.
   */
  @Deprecated
  public BasicAuthIdentityProvider getBasicAuth();
  public BasicAuthIdentityProvider buildBasicAuth();
  public A withBasicAuth(BasicAuthIdentityProvider basicAuth);
  public Boolean hasBasicAuth();
  public IdentityProviderFluent.BasicAuthNested<A> withNewBasicAuth();
  public IdentityProviderFluent.BasicAuthNested<A> withNewBasicAuthLike(BasicAuthIdentityProvider item);
  public IdentityProviderFluent.BasicAuthNested<A> editBasicAuth();
  public IdentityProviderFluent.BasicAuthNested<A> editOrNewBasicAuth();
  public IdentityProviderFluent.BasicAuthNested<A> editOrNewBasicAuthLike(BasicAuthIdentityProvider item);
  
  /**
   * This method has been deprecated, please use method buildGithub instead.
   * @return The buildable object.
   */
  @Deprecated
  public GitHubIdentityProvider getGithub();
  public GitHubIdentityProvider buildGithub();
  public A withGithub(GitHubIdentityProvider github);
  public Boolean hasGithub();
  public IdentityProviderFluent.GithubNested<A> withNewGithub();
  public IdentityProviderFluent.GithubNested<A> withNewGithubLike(GitHubIdentityProvider item);
  public IdentityProviderFluent.GithubNested<A> editGithub();
  public IdentityProviderFluent.GithubNested<A> editOrNewGithub();
  public IdentityProviderFluent.GithubNested<A> editOrNewGithubLike(GitHubIdentityProvider item);
  
  /**
   * This method has been deprecated, please use method buildGitlab instead.
   * @return The buildable object.
   */
  @Deprecated
  public GitLabIdentityProvider getGitlab();
  public GitLabIdentityProvider buildGitlab();
  public A withGitlab(GitLabIdentityProvider gitlab);
  public Boolean hasGitlab();
  public IdentityProviderFluent.GitlabNested<A> withNewGitlab();
  public IdentityProviderFluent.GitlabNested<A> withNewGitlabLike(GitLabIdentityProvider item);
  public IdentityProviderFluent.GitlabNested<A> editGitlab();
  public IdentityProviderFluent.GitlabNested<A> editOrNewGitlab();
  public IdentityProviderFluent.GitlabNested<A> editOrNewGitlabLike(GitLabIdentityProvider item);
  
  /**
   * This method has been deprecated, please use method buildGoogle instead.
   * @return The buildable object.
   */
  @Deprecated
  public GoogleIdentityProvider getGoogle();
  public GoogleIdentityProvider buildGoogle();
  public A withGoogle(GoogleIdentityProvider google);
  public Boolean hasGoogle();
  public IdentityProviderFluent.GoogleNested<A> withNewGoogle();
  public IdentityProviderFluent.GoogleNested<A> withNewGoogleLike(GoogleIdentityProvider item);
  public IdentityProviderFluent.GoogleNested<A> editGoogle();
  public IdentityProviderFluent.GoogleNested<A> editOrNewGoogle();
  public IdentityProviderFluent.GoogleNested<A> editOrNewGoogleLike(GoogleIdentityProvider item);
  
  /**
   * This method has been deprecated, please use method buildHtpasswd instead.
   * @return The buildable object.
   */
  @Deprecated
  public HTPasswdIdentityProvider getHtpasswd();
  public HTPasswdIdentityProvider buildHtpasswd();
  public A withHtpasswd(HTPasswdIdentityProvider htpasswd);
  public Boolean hasHtpasswd();
  public IdentityProviderFluent.HtpasswdNested<A> withNewHtpasswd();
  public IdentityProviderFluent.HtpasswdNested<A> withNewHtpasswdLike(HTPasswdIdentityProvider item);
  public IdentityProviderFluent.HtpasswdNested<A> editHtpasswd();
  public IdentityProviderFluent.HtpasswdNested<A> editOrNewHtpasswd();
  public IdentityProviderFluent.HtpasswdNested<A> editOrNewHtpasswdLike(HTPasswdIdentityProvider item);
  
  /**
   * This method has been deprecated, please use method buildKeystone instead.
   * @return The buildable object.
   */
  @Deprecated
  public KeystoneIdentityProvider getKeystone();
  public KeystoneIdentityProvider buildKeystone();
  public A withKeystone(KeystoneIdentityProvider keystone);
  public Boolean hasKeystone();
  public IdentityProviderFluent.KeystoneNested<A> withNewKeystone();
  public IdentityProviderFluent.KeystoneNested<A> withNewKeystoneLike(KeystoneIdentityProvider item);
  public IdentityProviderFluent.KeystoneNested<A> editKeystone();
  public IdentityProviderFluent.KeystoneNested<A> editOrNewKeystone();
  public IdentityProviderFluent.KeystoneNested<A> editOrNewKeystoneLike(KeystoneIdentityProvider item);
  
  /**
   * This method has been deprecated, please use method buildLdap instead.
   * @return The buildable object.
   */
  @Deprecated
  public LDAPIdentityProvider getLdap();
  public LDAPIdentityProvider buildLdap();
  public A withLdap(LDAPIdentityProvider ldap);
  public Boolean hasLdap();
  public IdentityProviderFluent.LdapNested<A> withNewLdap();
  public IdentityProviderFluent.LdapNested<A> withNewLdapLike(LDAPIdentityProvider item);
  public IdentityProviderFluent.LdapNested<A> editLdap();
  public IdentityProviderFluent.LdapNested<A> editOrNewLdap();
  public IdentityProviderFluent.LdapNested<A> editOrNewLdapLike(LDAPIdentityProvider item);
  public String getMappingMethod();
  public A withMappingMethod(String mappingMethod);
  public Boolean hasMappingMethod();
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  
  /**
   * This method has been deprecated, please use method buildOpenID instead.
   * @return The buildable object.
   */
  @Deprecated
  public OpenIDIdentityProvider getOpenID();
  public OpenIDIdentityProvider buildOpenID();
  public A withOpenID(OpenIDIdentityProvider openID);
  public Boolean hasOpenID();
  public IdentityProviderFluent.OpenIDNested<A> withNewOpenID();
  public IdentityProviderFluent.OpenIDNested<A> withNewOpenIDLike(OpenIDIdentityProvider item);
  public IdentityProviderFluent.OpenIDNested<A> editOpenID();
  public IdentityProviderFluent.OpenIDNested<A> editOrNewOpenID();
  public IdentityProviderFluent.OpenIDNested<A> editOrNewOpenIDLike(OpenIDIdentityProvider item);
  
  /**
   * This method has been deprecated, please use method buildRequestHeader instead.
   * @return The buildable object.
   */
  @Deprecated
  public RequestHeaderIdentityProvider getRequestHeader();
  public RequestHeaderIdentityProvider buildRequestHeader();
  public A withRequestHeader(RequestHeaderIdentityProvider requestHeader);
  public Boolean hasRequestHeader();
  public IdentityProviderFluent.RequestHeaderNested<A> withNewRequestHeader();
  public IdentityProviderFluent.RequestHeaderNested<A> withNewRequestHeaderLike(RequestHeaderIdentityProvider item);
  public IdentityProviderFluent.RequestHeaderNested<A> editRequestHeader();
  public IdentityProviderFluent.RequestHeaderNested<A> editOrNewRequestHeader();
  public IdentityProviderFluent.RequestHeaderNested<A> editOrNewRequestHeaderLike(RequestHeaderIdentityProvider item);
  public String getType();
  public A withType(String type);
  public Boolean hasType();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface BasicAuthNested<N> extends Nested<N>,BasicAuthIdentityProviderFluent<IdentityProviderFluent.BasicAuthNested<N>>{
    public N and();
    public N endBasicAuth();
    
  }
  public interface GithubNested<N> extends Nested<N>,GitHubIdentityProviderFluent<IdentityProviderFluent.GithubNested<N>>{
    public N and();
    public N endGithub();
    
  }
  public interface GitlabNested<N> extends Nested<N>,GitLabIdentityProviderFluent<IdentityProviderFluent.GitlabNested<N>>{
    public N and();
    public N endGitlab();
    
  }
  public interface GoogleNested<N> extends Nested<N>,GoogleIdentityProviderFluent<IdentityProviderFluent.GoogleNested<N>>{
    public N and();
    public N endGoogle();
    
  }
  public interface HtpasswdNested<N> extends Nested<N>,HTPasswdIdentityProviderFluent<IdentityProviderFluent.HtpasswdNested<N>>{
    public N and();
    public N endHtpasswd();
    
  }
  public interface KeystoneNested<N> extends Nested<N>,KeystoneIdentityProviderFluent<IdentityProviderFluent.KeystoneNested<N>>{
    public N and();
    public N endKeystone();
    
  }
  public interface LdapNested<N> extends Nested<N>,LDAPIdentityProviderFluent<IdentityProviderFluent.LdapNested<N>>{
    public N and();
    public N endLdap();
    
  }
  public interface OpenIDNested<N> extends Nested<N>,OpenIDIdentityProviderFluent<IdentityProviderFluent.OpenIDNested<N>>{
    public N and();
    public N endOpenID();
    
  }
  public interface RequestHeaderNested<N> extends Nested<N>,RequestHeaderIdentityProviderFluent<IdentityProviderFluent.RequestHeaderNested<N>>{
    public N and();
    public N endRequestHeader();
    
  }
  
}
